@@ -386,7 +386,7 @@ class MLGroundTruthMixin:
         user_id=None,
         temporal_version=datetime.datetime.utcnow().isoformat(),
         label=None,
-        focus_view=False,
+        include_sentences=False,
     ):
         """Returns a item of the provided project enriched with Ground Truth data.
 
@@ -397,22 +397,26 @@ class MLGroundTruthMixin:
         :param user_id: Id of the user to filter Ground Truth by
         :param temporal_version: Temporal version of the Ground Truth
         :param label: Label tag to filter Ground Truth by
-        :param focus_view: Flag to return documents split in sentences
+        :param include_sentences: Flag to return documents split in sentences
         :return:
         """
         base_url = "{}/v0/{}/projects/{}/groundtruths/{}/items/{}"
         headers = {"Content-Type": "application/json"}
 
-        data = {
-            "user_id": user_id,
-            "temporal_version": temporal_version,
-            "label": label,
-            "highlight_query": highlight_query,
-            "focus_view": focus_view,
-        }
+        data = json.dumps(
+            {
+                "data": {
+                    "highlight_query": highlight_query,
+                    "label": label,
+                    "user_id": user_id,
+                    "temporal_version": temporal_version,
+                    "include_sentences": include_sentences,
+                }
+            }
+        )
 
         url = base_url.format(
             self.topic_api_url, self.tenant, project_id, groundtruth_id, item_id
         )
-        res = self._perform_request("get", url, headers=headers, params=data)
+        res = self._perform_request("get", url, headers=headers, data=data)
         return self._process_response(res)
